@@ -7,11 +7,16 @@ sub transform {
     delete $watchSource->{template};
     my $owner   = delete $watchSource->{owner};
     my $project = delete $watchSource->{project};
-    die 'Missing owner'   unless $owner;
-    die 'Missing project' unless $project;
+    my $dist    = delete $watchSource->{dist};
+    die 'Missing Owner/Project or Dist' unless $dist or ($owner and $project);
+    if ($dist) {
+        $dist =~ s#^.*?github\.com#https://api.github.com#;
+        $dist =~ s/\.git$//;
+    } else {
+        $dist = "https://api.github.com/repos/$owner/$project";
+    }
 
-    $watchSource->{source}
-      ||= "https://api.github.com/repos/$owner/$project/git/matching-refs/"
+    $watchSource->{source} ||= "$dist/git/matching-refs/"
       . ($watchSource->{releaseonly} ? 'release/' : 'tags/');
     $watchSource->{matchingpattern}
       ||= 'https://api.github.com/repos/[^/]+/[^/]+/git/refs/tags/(?>[^/]+(?<=(?:\D|alpha|beta|rc))\-)?'
