@@ -241,7 +241,9 @@ if ($use_dctrl) {
         exec       => ['dpkg-query', '-W', '-f', '${source:Version}', 'apt'],
         to_string  => \$apt_version,
         wait_child => 1,
-        nocheck    => 1
+        no_check   => 1,
+        # XXX: Backwards compatibility, remove after dpkg 1.24.0.
+        nocheck => 1,
     );
 
     my $useAptHelper = 0;
@@ -262,7 +264,9 @@ if ($use_dctrl) {
                 to_string       => \$sources,
                 error_to_string => \$err,
                 wait_child      => 1,
-                nocheck         => 1
+                no_check        => 1,
+                # XXX: Backwards compatibility, remove after dpkg 1.24.0.
+                nocheck => 1,
             );
             if ($? >> 8) {
                 die "Unable to get list of Sources files from apt: $err\n";
