@@ -19,6 +19,7 @@ use strict;
 use warnings;
 use Cwd;
 use Dpkg::IPC;
+use Dpkg::Path qw(find_command);
 use File::Copy qw(cp move);
 use File::Basename;
 use File::Spec;
@@ -86,6 +87,7 @@ Valid options are:
    --quiet, -q            Be quiet if no differences were found
    --exclude PATTERN      Exclude files whose basenames match PATTERN
    --ignore-space, -w     Ignore whitespace in diffs
+   --no-check             Do not check signatures and checksums before unpacking
    --diffstat             Include the result of diffstat before the diff
    --no-diffstat          Do not do so (default)
    --auto-ver-sort        When comparing source packages, ensure the
@@ -126,6 +128,7 @@ my $controlfiles         = 'control';
 my $show_moved           = 0;
 my $wdiff_opt            = '';
 my @diff_opts            = ();
+my $check_source         = 1;
 my $show_diffstat        = 0;
 my $wdiff_source_control = 0;
 my $auto_ver_sort        = 0;
@@ -148,6 +151,7 @@ if (@ARGV and $ARGV[0] =~ /^--no-?conf$/) {
         'DEBDIFF_CONTROLFILES'         => 'control',
         'DEBDIFF_SHOW_MOVED'           => 'no',
         'DEBDIFF_WDIFF_OPT'            => '',
+        'DEBDIFF_CHECK_SOURCE'         => 'yes',
         'DEBDIFF_SHOW_DIFFSTAT'        => 'no',
         'DEBDIFF_WDIFF_SOURCE_CONTROL' => 'no',
         'DEBDIFF_AUTO_VER_SORT'        => 'no',
@@ -176,6 +180,8 @@ if (@ARGV and $ARGV[0] =~ /^--no-?conf$/) {
       or $config_vars{'DEBDIFF_CONTROL'} = 'yes';
     $config_vars{'DEBDIFF_SHOW_MOVED'} =~ /^(yes|no)$/
       or $config_vars{'DEBDIFF_SHOW_MOVED'} = 'no';
+    $config_vars{'DEBDIFF_CHECK_SOURCE'} =~ /^(yes|no)$/
+      or $config_vars{'DEBDIFF_CHECK_SOURCE'} = 'yes';
     $config_vars{'DEBDIFF_SHOW_DIFFSTAT'} =~ /^(yes|no)$/
       or $config_vars{'DEBDIFF_SHOW_DIFFSTAT'} = 'no';
     $config_vars{'DEBDIFF_WDIFF_SOURCE_CONTROL'} =~ /^(yes|no)$/
@@ -207,6 +213,7 @@ if (@ARGV and $ARGV[0] =~ /^--no-?conf$/) {
     $controlfiles    = $config_vars{'DEBDIFF_CONTROLFILES'};
     $show_moved = $config_vars{'DEBDIFF_SHOW_MOVED'} eq 'yes'       ? 1  : 0;
     $wdiff_opt  = $config_vars{'DEBDIFF_WDIFF_OPT'} =~ /^-([plt])$/ ? $1 : '';
+    $check_source  = $config_vars{'DEBDIFF_CHECK_SOURCE'} eq 'yes'  ? 1  : 0;
     $show_diffstat = $config_vars{'DEBDIFF_SHOW_DIFFSTAT'} eq 'yes' ? 1  : 0;
     $wdiff_source_control
       = $config_vars{'DEBDIFF_WDIFF_SOURCE_CONTROL'} eq 'yes' ? 1 : 0;
@@ -319,6 +326,9 @@ while (@ARGV) {
     } elsif ($ARGV[0] =~ /^(--ignore-space|-w)$/) {
         push @diff_opts, "-w";
         shift;
+    } elsif ($ARGV[0] eq '--no-check') {
+        $check_source = 0;
+        shift;
     } elsif ($ARGV[0] eq '--diffstat') {
         $show_diffstat = 1;
         shift;
@@ -634,12 +644,9 @@ if ($type eq 'deb') {
     }
 
     # Do we have interdiff?
-    system("command -v interdiff >/dev/null 2>&1");
-    my $use_interdiff = ($? == 0) ? 1 : 0;
-    system("command -v diffstat >/dev/null 2>&1");
-    my $have_diffstat = ($? == 0) ? 1 : 0;
-    system("command -v wdiff >/dev/null 2>&1");
-    my $have_wdiff = ($? == 0) ? 1 : 0;
+    my $use_interdiff = !!find_command('interdiff');
+    my $have_diffstat = !!find_command('diffstat');
+    my $have_wdiff    = !!find_command('wdiff');
 
     my ($fh, $filename) = tempfile(
         "debdiffXXXXXX",
@@ -716,6 +723,9 @@ if ($type eq 'deb') {
     for my $i (1, 2) {
         no strict 'refs';
         my @opts = ('-x');
+        if ($check_source eq 'no') {
+            push @opts, '--no-check';
+        }
         if ($dscformats[$i] eq '3.0 (quilt)' && !$apply_patches) {
             push @opts, '--skip-patches';
         }
@@ -1067,7 +1077,7 @@ if (defined $singledeb[1] and defined $singledeb[2]) {
 
 exit $exit_status unless (@CommonDebs > 0) and $compare_control;
 
-unless (system("command -v wdiff >/dev/null 2>&1") == 0) {
+if (!find_command('wdiff')) {
     warn "Can't compare control files; wdiff package not installed\n";
     exit $exit_status;
 }
